# h_devops v0.3.1

_Python support package from 3.6 and up_

---

# How to install

Please run this command on your terminal window 🎉️ 

```shell
$ pip install h-devops
```

or

```shell
$ pip3 install h-devops
```

---

# How to use

Welcome to my world 😄 

Now you can use the package with alias **h-devops**

```shell
$ h-devops --help
```

> Oh !! You will most likely encounter problems during use. I'm so sorry about this. :'(
>
> If you don't mind, you can **feedback** the error to me by email: **levuthanhtung11@gmail.com**
>
> I am so happy about that ❤️ 
>
> Author: Võ Hoàng
